
# THIS FILE IS GENERATED FROM NUMPY SETUP.PY
short_version = '1.6.2'
version = '1.6.2'
full_version = '1.6.2'
git_revision = 'ca07bce202ae26b6f0a73870eb2ef0b88e0210c5'
release = True

if not release:
    version = full_version



import sys
from numpy.testing import *
from f2py_ext import fib2

class TestFib2(TestCase):

    def test_fib(self):
        assert_array_equal(fib2.fib(6),[0,1,1,2,3,5])

if __name__ == "__main__":
    run_module_suite()
